:root {
    interpolate-size: allow-keywords;
    --color-blue: #47A1BB;
    --color-dark-blue: #295561;
    --color-orange: #FF511B;
    --color-red: #FF113F;
    --color-white: #F6FBFF;
    --color-light-black: #141715;
    --color-black: #000;


    --space-8: 0.5rem;
    --space-12: 0.75rem;
    --space-16: 1rem;
    --space-24: 1.5rem;
    --space-32: 2rem;
    --space-40: 2.5rem;
    --space-48: 3rem;
    --space-56: 3.5rem;
    --space-64: 4rem;
    --space-72: 4.5rem;
    --space-96: 6rem;
    --space-120: 7.5rem;

    --font-size-large: 2rem;
    --font-size-small-display: 4rem;
    --font-size-medium-display: 4.8125rem;
    --font-size-display: 6rem;
    --font-size-x-display: 8rem;
    --font-size-xx-display: 9.75rem;
}

*,
*::before,
*::after {
    box-sizing: border-box;
}

html {
    scroll-behavior: smooth;
    overflow-x: hidden;
}

img,
svg {
    max-width: 100%;
    height: auto;
    display: block;
}

.container {
    margin: 0 auto;
    max-width: 60rem;
}

.visually-hidden {
    clip: rect(0 0 0 0);
    clip-path: inset(50%);
    height: 1px;
    overflow: hidden;
    position: absolute;
    white-space: nowrap;
    width: 1px;
}

.hide {
    display: none;
}


body {
    background-color: var(--color-light-black);
    overflow: hidden;
    width: 100%;
}

/*Header*/

.header {
    width: 100%;
    min-height: 115vh;
    background-repeat: no-repeat;
    background-position: center;
    background-size: cover;
}

.homepage__bg {
    background-image: url(../assets/homepage-fold.webp);
}

.header__grid {
    display: grid;
    grid-template-rows: 110px 480px 200px auto;
}

.header__title {
    grid-row: 2;
    display: grid;
    grid-template-columns: 1fr;
    align-items: center;
    justify-content: start;
}

.header__title__bg,
.header__title__text {
    grid-column: 1/-1;
    grid-row: 1/-1;
}


.header__title__bg {
    width: 70%;
}

.header__title__text {
    margin-left: 110px;
    margin-top: -44px;
    transform: rotate(-4.325deg);
}

.header__bodycopy {
    display: grid;
    grid-template-columns: 6rem 1fr auto 6rem;
    grid-row: 3;
    grid-column: 1/-1;
}

.header__bodycopy__content {
    grid-column: 2;
    display: flex;
    flex-direction: column;
}

.header__bodycopy__content div:first-child {
    align-self: flex-start;
}

.header__bodycopy__content div:last-child {
    align-self: flex-start;
    margin-top: auto;
}

.header__bodycopy__cta {
    display: flex;
    gap: var(--space-32);
}

.header__divider {
    grid-row: 4;
    display: flex;
    align-items: flex-end;
}

.header__divider svg:first-child {
    width: 45%;
}

.header__divider svg:last-child {
    width: 55%;
}

/*Navbar*/

.navigation {
    position: absolute;
    width: 100%;
    top: 2%;
    left: 0%;
    z-index: 100;
}

.navigation__menu {
    display: flex;
}

.navigation__list {
    display: flex;
    justify-content: center;
    align-items: center;
}

.navbar__homepage {
    margin-left: var(--space-32);
}

.navbar__website {
    margin-left: auto;
    margin-right: var(--space-72);
}

.navigation__links {
    color: var(--color-white);
    text-decoration: none;
    text-align: center;
    font-family: waverly-cf, sans-serif;
    font-size: 20px;
    font-style: normal;
    font-weight: 600;
    line-height: normal;
    letter-spacing: 0.4px;
    padding: 0 30px;
    position: relative;
}

.navigation__links::after {
    content: '';
    position: absolute;
    bottom: -5px;
    left: 50%;
    transform: translateX(-50%);
    width: 0;
    height: 2px;
    background-color: var(--color-white);
    transition: width 0.3s ease-in-out;
}

.navigation__links:hover::after {
    width: calc(100% - 60px);
}

.navigation__list li {
    border-right: 2px solid var(--color-white);
}

.navigation__list li:last-child {
    border-right: none;
}

.navigation__list .button__cta__1 {
    margin-left: var(--space-32);
}


/*Titles*/

h1 {
    color: #F6FBFF;
    text-shadow: 0 4px 4px rgba(0, 0, 0, 0.25);
    font-family: waverly-cf, sans-serif;
    font-size: var(--font-size-display);
    font-style: normal;
    font-weight: 900;
    line-height: 0.85;
    letter-spacing: -1.92px;
}

.roughtypo {
    color: var(--color-white);
    -webkit-text-stroke-color: var(--color-blue);
    font-family: thirsty-rough-two, sans-serif;
    font-style: normal;
    font-weight: 400;
    line-height: normal;
    letter-spacing: 1.54px;
    text-shadow: 0 4px 4px rgba(0, 0, 0, 0);
}

.roughtypo.display {
    font-size: var(--font-size-x-display);
    position: relative;
    z-index: 2;
    top: 20px;
    left: 10px;
}

.roughtypo.display::before {
    content: attr(data-text);
    font-size: var(--font-size-x-display);
    position: absolute;
    z-index: -1;
    -webkit-text-stroke-width: 15px;
}

.roughtypo.medium-display {
    font-size: var(--font-size-medium-display);
    position: relative;
    z-index: 2;
    display: inline-block;
    vertical-align: middle;
    transform: translateY(-10px);
}

.roughtypo.medium-display::before {
    content: attr(data-text);
    font-size: var(--font-size-medium-display);
    position: absolute;
    z-index: -1;
    -webkit-text-stroke-width: 12px;
}

.roughtypo.small-display {
    font-size: var(--font-size-small-display);
    position: relative;
    z-index: 2;
    display: inline-block;
    vertical-align: middle;
}

.roughtypo.small-display::before {
    content: attr(data-text);
    font-size: var(--font-size-small-display);
    position: absolute;
    z-index: -1;
    -webkit-text-stroke-width: 10px;
}

.roughtypo.display__tiny {
    font-size: var(--font-size-large);
    position: relative;
    z-index: 2;
    display: inline-block;
    vertical-align: middle;
}

.roughtypo.display__tiny::before {
    content: attr(data-text);
    font-size: var(--font-size-large);
    position: absolute;
    z-index: -1;
    -webkit-text-stroke-width: 5px;
}

.header__title__end {
    font-size: var(--font-size-x-display);
    vertical-align: middle;
    margin-left: 20px;
}

.header__title__text h1 span:last-child {
    -webkit-text-stroke-color: var(--color-blue);
    font-size: var(--font-size-xx-display);
    position: relative;
    z-index: 2;
    display: inline-block;
    vertical-align: middle;
    transform: translateX(var(--space-24)) rotate(11.91deg);
}

.header__title__text h1 span:last-child::before {
    content: attr(data-text);
    position: absolute;
    z-index: -1;
    font-size: var(--font-size-xx-display);
    -webkit-text-stroke-color: var(--color-blue);
    -webkit-text-stroke-width: 12px;
}

h2 {
    color: #F6FBFF;
    text-shadow: 0 4px 4px #000;
    font-family: waverly-cf, sans-serif;
    font-size: var(--font-size-small-display);
    font-style: normal;
    font-weight: 900;
    line-height: 0.9;
    margin: 0;
}

h2 span:first-of-type {
    font-size: var(--font-size-display);
}

h3 {
    color: var(--color-white);
    font-family: waverly-cf, sans-serif;
    font-size: var(--font-size-large);
    font-style: normal;
    font-weight: 700;
    line-height: 150%;
    letter-spacing: 0.64px;
}

p {
    color: var(--color-white);
    font-family: itc-avant-garde-gothic-pro, sans-serif;
    font-size: 16px;
    font-style: normal;
    font-weight: 300;
    line-height: 150%;
    letter-spacing: 0.32px;
}

p em {
    font-weight: 600;
}

.subtitle p {
    color: var(--color-white);
    font-family: itc-avant-garde-gothic-pro, sans-serif;
    font-size: 20px;
    font-style: normal;
    font-weight: 300;
    line-height: 150%;
    letter-spacing: 0.4px;
}

.text__highlight {
    font-family: waverly-cf, sans-serif;
    font-size: 20px;
    font-style: normal;
    font-weight: 800;
    letter-spacing: 0.4px;
}

/*Buttons*/
.button__cta__1 {
    display: inline-flex;
    font-family: waverly-cf, sans-serif;
    font-size: 20px;
    font-style: normal;
    font-weight: 800;
    line-height: normal;
    letter-spacing: 0.4px;
    text-decoration: none;

    padding: 14px 16px;
    justify-content: center;
    align-items: center;
    gap: 10px;
    background-color: var(--color-white);
    box-shadow: 0 4px 4px 0 rgba(0, 0, 0, 0.15);
    color: var(--color-blue);
    transition: all 0.3s ease-in-out;
    border: 3px solid transparent;
}

.button__cta__1:hover {
    color: var(--color-white);
    background-color: var(--color-blue);
}

.button__cta__2 {
    display: inline-flex;
    font-family: waverly-cf, sans-serif;
    font-size: 20px;
    font-style: normal;
    font-weight: 900;
    line-height: normal;
    letter-spacing: 0.4px;
    text-decoration: none;

    padding: 14px 16px;
    justify-content: center;
    align-items: center;
    gap: 10px;
    background: transparent;
    box-shadow: 0 4px 4px 0 rgba(0, 0, 0, 0.15);
    border: 3px solid var(--color-white);
    color: var(--color-white);
    transition: all 0.3s ease-in-out;
}

.button__cta__2:hover {
    color: var(--color-blue);
    background: var(--color-white);
}


/*why section*/
.why__section {
    position: relative;
    z-index: 3;
    background-color: var(--color-light-black);
    min-height: 100vh;
    padding-top: 6rem;
    padding-bottom: 8rem;
}

.why__section__bg {
    position: absolute;
    top: 0;
    left: 0;
    z-index: 0;
    margin-top: -7.8rem;
    pointer-events: none;
}

.why__global__wrapper {
    position: relative;
    z-index: 5;
    width: 100%;
}

.why__bg__orange {
    position: absolute;
    z-index: 0;
    top: 45%;
    left: 15%;
    width: 65%;
    opacity: 0;
    pointer-events: none;
    transition: opacity 0.5s ease-in-out;
}

.why__section__grid {
    position: relative;
    z-index: 10;
    display: grid;
    grid-template-columns: 8rem 1fr 47%;
    width: 100%;
}

.why__content__left {
    grid-column: 2;
    display: flex;
    flex-direction: column;
}

.why__bodycopy__description {
    display: flex;
    flex-direction: column;
    gap: var(--space-32);
}

.why__bodycopy__description h2 {
    transform: rotate(-4.325deg);
}

.why__bodycopy__description p {
    margin-top: var(--space-40);
}

.why__lamp__interaction {
    position: relative;
    display: grid;
    grid-template-columns: 18rem 1fr;
    align-items: center;
    margin-top: var(--space-72);
}

.why__lamp__trigger {
    position: absolute;
    left: -10rem;
    top: 80%;
    transform: translateY(-50%);
    width: 24rem;
    z-index: 20;
}

.why__flashlight__base {
    width: 100%;
    cursor: pointer;
    transform: rotate(-5.052deg);
}

.why__flashlight__hover {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    transform: rotate(-5.052deg);
    opacity: 0;
    pointer-events: none;
    transition: opacity 0.2s ease-in-out;
}

.why__lamp__trigger:hover .why__flashlight__hover {
    opacity: 1;
}

.why__section__grid:not(.state__light__on) .why__lamp__trigger:hover .why__flashlight__hover {
    opacity: 1;
}

.why__interaction__wrapper {
    grid-column: 2;
    display: grid;
    grid-template-columns: 1fr;
    grid-template-rows: 1fr;
}

.why__text__base,
.why__text__revealed {
    grid-column: 1/2;
    grid-row: 1/2;
    transition: opacity 0.5s ease-in-out;
}

.why__text__base {
    display: flex;
    flex-direction: column;
    gap: var(--space-24);
}

.why__text__base h3 {
    transform: rotate(-4.32deg);
    margin-bottom: -2rem;
}

.why__text__base p {
    margin-left: var(--space-56);
}

.why__text__base p:first-of-type {
    margin-left: var(--space-48);
    margin-top: var(--space-40);
}

.why__text__base p:last-of-type {
    margin-left: var(--space-64);
}

.why__text__revealed {
    opacity: 0;
    pointer-events: none;
    display: flex;
    flex-direction: column;
    gap: var(--space-24);
    width: 130%;
}

.why__revealed__content {
    transform: rotate(-4.32deg);
    display: flex;
    flex-direction: column;
    gap: var(--space-16);
}

.why__revealed__content h3 {
    margin-top: var(--space-24);
    transform: rotate(-2.786deg);
    margin-bottom: var(--space-8);
}

.why__revealed__content p:first-of-type {
    font-size: 20px;
}


.why__lamp__character {
    justify-self: end;
    grid-column: 3;
    position: relative;
    z-index: 20;
    display: flex;
    align-items: center;
    justify-content: flex-end;
}

.why__character__image {
    width: 100%;
    transition: opacity 0.5s ease-in-out;
    margin-top: -9rem;
}

.why__character__on {
    position: absolute;
    opacity: 0;
}

.why__telephone__cord {
    width: 26%;
    position: absolute;
    z-index: -1;
    pointer-events: none;
    top: 70%;
    right: 20%;
}

.why__cta__hint {
    margin-top: var(--space-48);
    margin-left: -6rem;
    display: flex;
    align-items: center;
    gap: 12px;
}

.why__cta__hint p {
    color: var(--color-white);
    font-family: itc-avant-garde-gothic-pro, sans-serif;
    font-size: 16px;
    font-weight: 300;
    margin: 0 !important;
}

.why__cta__button {
    position: relative;
    display: inline-flex;
    align-items: center;
    justify-content: center;
    width: 200px;
    height: 60px;
}

.why__cta__button svg {
    position: absolute;
    z-index: -1;
    width: 100%;
    height: 100%;
}

.why__cta__button span {
    color: var(--color-white);
    font-family: waverly-cf, sans-serif;
    font-size: 32px;
    font-style: normal;
    font-weight: 700;
    line-height: normal;
    letter-spacing: 0.64px;
    margin-top: -12px;
}

/*why javascript*/

.why__global__wrapper.state__light__on .why__bg__orange {
    opacity: 1;
}

.why__global__wrapper.state__light__on .why__text__base {
    opacity: 0;
    pointer-events: none;
}

.why__global__wrapper.state__light__on .why__text__revealed {
    opacity: 1;
    pointer-events: auto;
}

.why__global__wrapper.state__light__on .why__character__off {
    opacity: 0;
}

.why__global__wrapper.state__light__on .why__character__on {
    opacity: 1;
}

/*what*/

.what__section__main {
    position: relative;
    z-index: 2;
    min-height: 140vh;
    background-color: var(--color-orange);
    background-image: url('../assets/background_section_3.webp');
    background-size: cover;
    background-position: top;
    background-repeat: no-repeat;
    padding-top: var(--space-120);
}

.what__title__svg {
    position: absolute;
    z-index: 0;
    top: 10rem;
    left: 27%;
    width: 46%;
    pointer-events: none;
}

.what__title__container {
    position: relative;
    z-index: 10;
    display: flex;
    flex-direction: column;
    align-items: center;
    text-align: center;
}

.what__title__container h2 {
    transform: rotate(-2.305deg);
    text-shadow: 0 4px 4px rgba(0, 0, 0, 0.25);
}

.what__content__container {
    display: grid;
    grid-template-columns: 1fr 1fr;
    padding-right: 8rem;
    padding-left: 8rem;
    padding-top: var(--space-64);
    padding-bottom: var(--space-96);
    align-items: start;
}

.what__content__bodycopy {
    padding-top: var(--space-24);
    display: flex;
    flex-direction: column;
    gap: var(--space-16);
}

.what__content__bodycopy p:last-of-type {
    margin-top: var(--space-16);
}

.what__content__btn {
    margin-top: var(--space-32);
}

.what__accordion__wrapper {
    position: relative;
    z-index: 10;
    background-image: url('../assets/woodchest.webp');
    background-size: cover;
    background-position: center top;
    background-repeat: no-repeat;

    display: flex;
    flex-direction: column;
    align-items: center;
    padding: var(--space-48) 0;
    min-height: 600px;
}

.what__accordion__header {
    background-color: var(--color-white);
    width: 85%;
    text-align: center;
    padding: var(--space-12);
    font-family: waverly-cf, sans-serif;
    font-size: 20px;
    font-style: normal;
    font-weight: 800;
    line-height: 150%;
    letter-spacing: 0.4px;
}

.what__accordion__header h3 {
    color: var(--color-dark-blue);
}

.what__accordion__header h3 span {
    font-family: itc-avant-garde-gothic-pro, sans-serif;
    font-size: 20px;
    font-weight: 300;
    letter-spacing: 0.4px;
}


.what__accordion__item {
    background-color: var(--color-blue);
    border: 7px solid var(--color-white);
    color: var(--color-white);
    width: 85%;
    margin-bottom: -7px;
    transition: background-color 0.3s ease;
    padding: var(--space-12) 0 var(--space-12) 0;
}

.what__accordion__summary {
    padding: var(--space-16) var(--space-24);
    font-family: waverly-cf, sans-serif;
    font-size: 20px;
    font-style: normal;
    font-weight: 800;
    line-height: 150%;
    letter-spacing: 0.4px;
    cursor: pointer;
    list-style: none;
    position: relative;

    display: flex;
    justify-content: space-between;
    align-items: center;
}

.what__accordion__arrow {
    transition: transform 0.3s cubic-bezier(0.4, 0, 0.2, 1);
}

.what__accordion__item[open] .what__accordion__arrow--left {
    transform: rotate(-90deg);
}

.what__accordion__item[open] .what__accordion__arrow--right {
    transform: rotate(90deg);
}

.what__accordion__content {
    padding: 0 var(--space-24) 0 var(--space-24);
}

.what__accordion__content p {
    font-family: itc-avant-garde-gothic-pro, sans-serif;
    font-size: 16px;
    font-style: normal;
    font-weight: 300;
    line-height: 150%;
    letter-spacing: 0.32px;
    margin: 0;
    text-align: start;
}


.what__accordion__item::details-content {
    transition: content-visibility 0.4s allow-discrete,
        height 0.4s allow-discrete;
    height: 0;
    overflow: clip;
    box-shadow: 0;
}

.what__accordion__item[open]::details-content {
    height: auto;
}

.what__accordion__item[open] {
    background-color: var(--color-dark-blue);
    z-index: 2;
    position: relative;
    box-shadow: 0 4px 4px 0 rgba(0, 0, 0, 0.25);
}


/*how*/
.how__section__main {
    position: relative;
    z-index: 3;
    margin-top: -15rem;
    min-height: 100vh;
    padding-top: var(--space-120);
}

.how__background__wrapper {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    z-index: 0;
    pointer-events: none;
}

.how__red__banner {
    position: absolute;
    top: -4rem;
    left: 0;
    width: 100%;
    height: auto;
}

.how__content__container {
    position: relative;
    z-index: 10;
    min-height: 60vh;
    margin-top: -64px;
}


.how__content__header {
    display: flex;
    justify-content: space-between;
    align-items: center;
    padding-left: 8rem;
    padding-right: var(--space-96);
    margin-bottom: -2rem;
}

.how__content__title {
    display: flex;
    flex-direction: column;
    gap: var(--space-24);
}

.how__content__title h2 {
    text-shadow: 0 4px 4px rgba(0, 0, 0, 0.25);
    line-height: var(--space-56);
}

.title__left__push {
    margin-left: var(--space-32);
}

.title__left__push:last-of-type {
    margin-left: var(--space-24);
}

.how__content__image {
    width: 35%;
    display: flex;
    transform: translateY(7.3rem);
    justify-content: flex-end;
}


.how__content__steps {
    display: grid;
    grid-template-columns: repeat(3, 1fr);
    gap: var(--space-48);
    padding-left: 8rem;
    padding-right: 6rem;
    min-height: 35rem;
}

.how__step {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
}

.how__step:nth-child(1) {
    align-self: start;
}

.how__step:nth-child(2) {
    align-self: center;
}

.how__step:nth-child(3) {
    align-self: end;
}

.step__number {
    color: var(--color-white);
    -webkit-text-stroke-color: var(--color-blue);
    font-family: thirsty-rough-two, sans-serif;
    font-size: var(--font-size-x-display);
    position: relative;
    z-index: 2;
    display: inline-block;
    margin-bottom: -4rem;
}

.step__number::before {
    content: attr(data-text);
    font-size: var(--font-size-x-display);
    -webkit-text-stroke-width: 12px;
    -webkit-text-stroke-color: var(--color-blue);
    position: absolute;
    z-index: -1;
    top: 0;
    left: 0;
}

.step__title,
.how__step>p:not(.step__number) {
    margin-left: 2rem;
}

.step__title {
    position: relative;
    display: inline-flex;
    align-items: center;
    justify-content: center;
    width: 233px;
    height: 57px;
    margin-bottom: var(--space-24);
    z-index: 1;
}

.step__title__svg {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 110%;
    z-index: -1;
}

.how__step:nth-child(2) .step__title {

    width: 270px;
}

.how__step:nth-child(3) .step__title {

    width: 310px;
}

.step__title p {
    color: var(--color-white);
    font-family: waverly-cf, sans-serif;
    font-size: 32px;
    font-style: normal;
    font-weight: 800;
    line-height: 150%;
    letter-spacing: 0.64px;
    margin-top: 0 !important;
}

.how__step>p:not(.step__number):not(.step__subinfo) {
    margin-bottom: var(--space-24);
}

.step__subinfo {
    color: var(--color-white);
    font-family: waverly-cf, sans-serif;
    font-size: 14px;
    font-style: normal;
    font-weight: 500;
    line-height: 150%;
    letter-spacing: 0.28px;
}


/*Dark section*/

.dark__section__main {
    position: relative;
    background-color: var(--color-light-black);
    min-height: 65vh;
    display: flex;
    align-items: center;
    justify-content: center;
    overflow: hidden;
    padding-bottom: 5rem;
}

.dark__section__main.js-dark-active {
    cursor: none;
}

.dark__hint__wrapper {
    position: absolute;
    z-index: 1;
    text-align: center;
    transition: opacity 0.5s ease;
    pointer-events: none;
}

.dark__hint__wrapper p {
    color: var(--color-white);
    font-size: 20px;
}

.dark__section__main:hover .dark__hint__wrapper {
    opacity: 0;
}

.dark__cursor {
    position: absolute;
    left: var(--mask-x);
    top: var(--mask-y);
    width: 60px;
    height: 60px;
    border: 2px solid var(--color-orange);
    border-radius: 50%;

    transform: translate(-50%, -50%);
    pointer-events: none;
    z-index: 100;
    opacity: 0;
    transition: opacity 0.3 ease;
}

.dark__section__main:hover .dark__cursor {
    opacity: 1;
}

.dark__content__wrapper {
    position: relative;
    display: block;
    width: 100%;
    height: 100%;
    z-index: 2;
    --mask-x: -1000px;
    --mask-y: -1000px;
    --mask-size: 250px;

}

.dark__content__wrapper.js-mask-active {
    -webkit-mask-image: radial-gradient(circle var(--mask-size) at var(--mask-x) var(--mask-y), rgba(0, 0, 0, 1)30%, rgba(0, 0, 0, 0)100%);
    mask-image: radial-gradient(circle var(--mask-size) at var(--mask-x) var(--mask-y), rgba(0, 0, 0, 1)30%, rgba(0, 0, 0, 0)100%);
}

.dark__content__grid {
    display: grid;
    grid-template-columns: 8rem 65%;
    align-items: flex-start;
    width: 100%;
    margin-bottom: var(--space-48);
    transform: translateY(8rem);
    z-index: 10;
}

.dark__content__text {
    grid-column: 2;
    display: flex;
    flex-direction: column;
    gap: var(--space-32);
    text-align: left;
}

.dark__content__image {
    display: flex;
    justify-content: flex-end;
    width: 100%;
}

.dark__content__image img {
    width: 40%;
    transform: translateY(-5rem);
}

.dark__separator__svg {
    position: absolute;
    bottom: 0;
    left: 0;
    width: 100%;
    z-index: 5;
    pointer-events: none;
}

.transcript__title__main {
    font-family: waverly-cf, sans-serif;
    font-size: 20px;
    font-weight: 600;
    color: var(--color-blue);
}

.transcript__quote__text {
    font-size: 28px;
    font-weight: 500;
    line-height: 140%;
    color: var(--color-white);
}

.transcript__meta__info {
    font-family: itc-avant-garde-gothic-pro, sans-serif;
    font-size: 16px;
    color: var(--color-white);
}

.transcript__conclusion__text {
    font-family: waverly-cf, sans-serif;
    font-size: 20px;
    font-weight: 800;
    color: var(--color-orange);
}

/*Call stories*/

.call__section__main {
    position: relative;
    background-color: var(--color-orange);
    margin-top: -2px;
}

.call__section__header {
    display: grid;
    grid-template-columns: 1.2fr 1fr;
    width: 100%;
    position: relative;
}

.call__section__text {
    display: flex;
    flex-direction: column;
    gap: var(--space-32);
    padding-top: var(--space-96);
}


.call__section__title {
    position: relative;
    display: flex;
    align-items: center;
}

.call__title__svg {
    position: absolute;
    left: 0;
    z-index: 0;
    pointer-events: none;
}

.call__section__image {
    position: relative;
}

.call__section__image img {
    position: absolute;
    top: -3rem;
    right: 0;
    width: 93%;
    height: auto;
    z-index: 10;
    /*pointer-events: none;*/
}

.call__section__title h2 {
    position: relative;
    z-index: 2;
    margin-left: 8rem;
    text-align: left;
    transform: rotate(-2.3deg);
    text-shadow: 0 4px 4px rgba(0, 0, 0, 0.25);
}

.call__subtitle {
    position: relative;
    z-index: 2;
    margin-left: 8rem;
    padding-right: var(--space-32);
}

.call__section__content {
    position: relative;
    display: flex;
    justify-content: center;
    gap: var(--space-32);
    padding: 14rem 4rem 4rem 4rem;
    margin-top: -6rem;
    z-index: 2;
}

.call__background__line {
    position: absolute;
    top: 25%;
    left: 0;
    width: 100%;
    height: auto;
    z-index: 0;
}

.call__footer__cta {
    display: flex;
    gap: var(--space-24);

}

.review__card {
    position: relative;
    z-index: 1;
    width: 30%;
    border: 7px solid var(--color-white);
    background: var(--color-blue);
    box-shadow: 0 4px 4px 0 rgba(0, 0, 0, 0.25);
    padding: var(--space-48) var(--space-24) var(--space-16) var(--space-24);
    display: flex;
    flex-direction: column;
    gap: var(--space-16);
}

.review__card:nth-of-type(1) {
    transform: rotate(-2deg);
}

.review__card:nth-of-type(2) {
    transform: rotate(2deg);
}

.review__card:nth-of-type(3) {
    transform: rotate(-2deg);
}

.review__card__pin {
    position: absolute;
    top: 15px;
    left: 50%;
    transform: translateX(-50%);
    z-index: 3;
}

.review__card__title {
    position: relative;
    display: inline-flex;
    align-items: center;
    padding: 0 var(--space-8) 0 var(--space-16);
    margin-left: -1.5rem;
    margin-bottom: var(--space-8);
}

.review__title__svg {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    z-index: -1;
}

.review__card__title h3 {
    color: var(--color-white);
    font-family: waverly-cf, sans-serif;
    font-size: 24px;
    font-style: normal;
    font-weight: 800;
    letter-spacing: 0.48px;
}

.review__card__subtitle {
    color: var(--color-white);
    font-family: waverly-cf, sans-serif;
    font-size: 20px;
    font-style: normal;
    font-weight: 600;
    line-height: 150%;
    letter-spacing: 0.4px;
    margin: 0;
}

.review__card__stress {
    display: flex;
    align-items: center;
    gap: var(--space-8);
    margin-bottom: var(--space-8);
}

.stress__label {
    color: var(--color-white);
    font-family: waverly-cf, sans-serif;
    font-size: 16px;
    font-style: normal;
    font-weight: 800;
    line-height: 150%;
    letter-spacing: 0.32px;
}

.stress__percent {
    color: var(--color-white);
    font-family: thirsty-rough-two, sans-serif;
    font-size: 16px;
    font-style: normal;
    font-weight: 400;
    line-height: 150%;
    letter-spacing: 0.32px;
}

.stress__chart {
    transform: translateY(-10px);
}

.call__section__footer {
    display: flex;
    justify-content: center;
    gap: var(--space-64);
    margin-bottom: var(--space-64);
}

.app__section__main {
    position: relative;
    z-index: 4;
    background-color: var(--color-light-black);
    padding-top: var(--space-96);
    padding-bottom: var(--space-64);
    overflow: hidden;
}

.app__background__arm {
    position: absolute;
    bottom: 0;
    right: 0;
    width: 53%;
    height: auto;
    z-index: 1;
}

.app__section__header {
    position: absolute;
    top: 5rem;
    left: 15%;
    z-index: 10;
    display: flex;
    flex-direction: column;
    justify-content: center;
    align-items: flex-start;
}

.app__section__content {
    position: relative;
    z-index: 2;
    display: grid;
    grid-template-columns: 33% 33% 1fr;
    align-items: center;
    width: 100%;
    padding-top: 8rem;
}

.app__title__svg {
    position: absolute;
    transform: translate(-16%, 2%);
    width: 100%;
    min-width: 650px;
    z-index: -1;
}

.app__section__header h2 {
    position: relative;
    z-index: 2;
    text-align: left;
    text-shadow: 0 4px 4px rgba(0, 0, 0, 0.25);
}

.app__section__eye {
    grid-column: 1;
    position: relative;
    display: flex;
    justify-content: center;
    align-items: center;
}

.eye__background {
    width: 100%;
    height: auto;
    display: block;
}

.eye__pupil {
    position: absolute;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -40%);
    width: 40%;
    height: auto;
    z-index: 2;
    transition: transform 0.1s ease-out;
}

.app__section__bodycopy {
    grid-column: 2;
    display: flex;
    flex-direction: column;
    gap: var(--space-24);
    margin-left: var(--space-24);
}

.app__section__bodycopy p:last-of-type {
    margin-top: var(--space-16);
    margin-bottom: var(--space-16);
}

.call__section__title h2 span:last-of-type {
    margin-left: var(--space-24);
}

.app__content__btn {
    margin-top: var(--space-8);
}

.footer__main {
    background-color: var(--color-red);
    padding: var(--space-64) 4rem var(--space-48) 4rem;
    position: relative;
    z-index: 10;
}

.footer__grid {
    display: grid;
    grid-template-columns: 35% 18% 18% 1fr;
    align-items: center;
    gap: var(--space-32);
    width: 100%;
}

.footer__logo__link img {
    width: 65%;
    height: auto;
    display: block;
}

.footer__column {
    display: flex;
    flex-direction: column;
    justify-content: center;
}

.footer__column__menu {
    flex-direction: row;
    align-items: center;
    justify-content: flex-start;
    gap: var(--space-32);
}

.footer__vertical__line {
    width: 3px;
    height: 160px;
    background-color: var(--color-white);
}

.footer__list {
    display: flex;
    flex-direction: column;
    gap: var(--space-32);
    list-style-type: none;
    padding: 0;
    margin: 0;
}

.footer__list a {
    color: var(--color-white);
    font-family: itc-avant-garde-gothic-pro, sans-serif;
    font-size: 16px;
    font-style: normal;
    font-weight: 300;
    line-height: normal;
    letter-spacing: 0.32px;
    text-decoration: none;
    position: relative;
    padding-bottom: 4px;
}

.footer__list a::after {
    content: '';
    position: absolute;
    bottom: 0;
    left: 0;
    width: 0;
    height: 1px;
    background-color: var(--color-white);
    transition: width 0.3s ease-in-out;
}

.footer__list a:hover::after {
    width: 100%;
}

.footer__column__end {
    align-items: flex-end;
    gap: 7rem;
}

.footer__copyright {
    color: #F6FBFF;
    text-align: right;
    font-family: itc-avant-garde-gothic-pro, sans-serif;
    font-size: 12px;
    font-style: normal;
    font-weight: 300;
    line-height: normal;
    letter-spacing: 0.24px;

}

/*Modal form*/

.story__modal {
    margin: auto;
    width: 90%;
    max-width: 1400px;
    border: 7px solid var(--color-white);
    background: var(--color-orange);
    background-image: url(../assets/backgroundform.webp);
    background-size: cover;
    background-position: center;
    background-repeat: no-repeat;
    box-shadow: 0 4px 4px 0 rgba(0, 0, 0, 0.25);
    padding: var(--space-48) var(--space-64);
    position: relative;
    z-index: 10;
}

.story__modal__container {
    display: grid;
    grid-template-columns: 1.1fr 1fr;
    gap: var(--space-64);
}

.story__modal__left {
    position: relative;
    display: flex;
    flex-direction: column;
}

.story__modal__right {
    padding-top: var(--space-56);
}

.story__modal__title {
    position: relative;
    margin-bottom: var(--space-32);
}

.modal__title__svg {
    position: absolute;
    top: 65px;
    left: -80px;
    z-index: -1;
}

.story__modal__title h2 {
    transform: rotate(-2.305deg);
    text-shadow: 0 4px 4px rgba(0, 0, 0, 0.25);
}

.modal__intro {
    color: var(--color-white);
    font-family: itc-avant-garde-gothic-pro, sans-serif;
    font-size: 20px;
    font-style: normal;
    font-weight: 600;
    line-height: 150%;
    letter-spacing: 0.4px;
    margin-bottom: var(--space-16);
}

.modal__progress {
    position: relative;
    margin-top: var(--space-48);
    margin-bottom: var(--space-48);
    display: flex;
    align-items: center;
    justify-content: center;
    width: 400px;
    height: 400px;
}

.progress__bg {
    position: absolute;
    width: 100%;
    height: 100%;
    z-index: 1;
}

.progress__text {
    position: relative;
    z-index: 2;
    text-align: center;
    transform: rotate(-5deg);
}

.progress__percent__display {
    font-family: thirsty-rough-two, sans-serif;
    font-size: 156px;
    font-weight: 400;
    line-height: 0.6;
    margin-top: var(--space-16);
}

.progress__label {
    font-family: waverly-cf, sans-serif;
    font-size: 30px;
    font-weight: 800;
}

#callStoryForm {
    display: flex;
    flex-direction: column;
    gap: 43px;
    align-items: flex-start;
}

.form__group {
    position: relative;
    display: flex;
    flex-direction: column;
    gap: 7px;
    width: 100%;
}

.form__group label:first-child {
    color: var(--color-white);
    font-family: itc-avant-garde-gothic-pro, sans-serif;
    font-size: 20px;
    font-weight: 500;
}

.form__group input[type="text"],
.form__group textarea {
    border: 3px solid var(--color-white);
    background: var(--color-dark-blue);
    padding: 12px 16px 8px 16px;
    color: var(--color-white);
    font-family: itc-avant-garde-gothic-pro, sans-serif;
    font-size: 16px;
    outline: none;
    transition: border-color 0.3s ease;
    max-width: 440px;
    width: 100%;
}

.form__group textarea {
    min-height: 150px;
    resize: none;
}

.form__group input:focus,
.form__group textarea:focus {
    border-color: var(--color-blue);
}

.form__group input::placeholder,
.form__group textarea::placeholder {
    color: #B7B7B7;
}

.form__footer__hints {
    display: flex;
    justify-content: space-between;
    margin-top: 4px;
    max-width: 440px;
}

.form__footer__hints .form__error__text {
    position: static;
}

.form__counter {
    color: var(--color-white);
    font-family: itc-avant-garde-gothic-pro, sans-serif;
    font-size: 14px;
    justify-self: end;
}

.form__error__text {
    color: #B71720;
    font-family: itc-avant-garde-gothic-pro, sans-serif;
    font-size: 16px;
    position: absolute;
    bottom: 0;
    left: 0;
    font-weight: 700;
    display: block;
    min-height: 20px;
    margin-top: 4px;
    letter-spacing: 0.32px;
    top: 5rem;
}

.radio__wrapper {
    display: flex;
    gap: var(--space-24);
}

.radio__item {
    display: flex;
    align-items: center;
    gap: 12px;
    padding: 8px 16px 8px 8px;
    border: 3px solid transparent;
    border-radius: 5px;
    cursor: pointer;
    transition: border-color 0.3 ease;
}

input[type="radio"]:checked~.radio__icon .radio-selected {
    opacity: 1;
}

input[type="radio"]:checked~.radio__icon .radio-unselected {
    opacity: 0;
}

.radio__item:has(input[type="radio"]:checked) {
    border-color: var(--color-white);
}

.radio__icon {
    position: relative;
    width: 24px;
    height: 24px;
    display: inline-block;
}

.radio-unselected,
.radio-selected {
    position: absolute;
    top: 0;
    left: 0;
    transition: opacity 0.2s ease;
}

.radio-selected {
    opacity: 0;
}

.radio__item span {
    color: var(--color-white);
    font-family: itc-avant-garde-gothic-pro, sans-serif;
    font-size: 16px;
}

.stress__selector__wrapper {
    display: flex;
    align-items: center;
    gap: var(--space-24);
    background-color: var(--color-dark-blue);
    border: 3px solid var(--color-white);
    padding: 8px 16px;
    width: fit-content;
}

.stress__arrow {
    background: transparent;
    border: none;
    color: var(--color-white);
    cursor: pointer;
    display: flex;
    align-items: center;
    justify-content: center;
    padding: 4px;
    transition: color 0.3s ease, transform 0.1s ease;
}

.stress__arrow:hover {
    color: var(--color-blue);
}

.stress__arrow:active {
    transform: scale(0.9);
}

.stress__arrow:disabled {
    color: #B7B7B7;
    cursor: not-allowed;
    transform: none;
}

.stress__value__display {
    display: flex;
    align-items: center;
    justify-content: center;
    min-width: 80px;
}

#stressInput {

    background: transparent;
    border: none;
    width: 55px;
    text-align: right;
    outline: none;
    font-family: thirsty-rough-two, sans-serif;
    font-size: 32px;
    color: var(--color-white);
}

#stressInput::-webkit-inner-spin-button,
#stressInput::-webkit-outer-spin-button {
    -webkit-appearance: none;
    margin: 0;
}

#stressInput.stress__input--no-js {
    border-bottom: 2px solid var(--color-white);
}

.stress__percent__symbol {
    font-family: thirsty-rough-two, sans-serif;
    font-size: 32px;
    color: var(--color-white);
}

.story__page__main {
    min-height: 100vh;
    background-color: var(--color-light-black);
    background-image: url('../assets/fold__error__404.webp');
    background-size: cover;
    background-position: center;
    background-repeat: no-repeat;
    display: flex;
    align-items: center;
    justify-content: center;
    padding: 180px 4rem 100px 4rem;
}

.story__modal__title h2 span:last-of-type {
    margin-left: var(--space-24);
}



.error__main {
    position: relative;
    align-items: flex-start;
    justify-content: flex-start;
    padding-top: 15rem;
}

.error__content {
    margin-left: 3rem;
    gap: var(--space-64);
}

.stories__page__main {
    position: relative;
    min-height: 100vh;
    padding-top: 15rem;
    padding-bottom: 8rem;
    z-index: 1;
    background: linear-gradient(0deg, #FF511B 9.49%, #141715 100%);
    background-attachment: fixed;
}

.stories__page__main::before {
    content: '';
    position: fixed;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
    width: 100vw;
    height: 100vh;
    background-image: url('../assets/ellipse_shape.webp');
    background-position: center;
    background-repeat: no-repeat;
    background-size: 40%;
    opacity: 0.2;

    z-index: -1;
    pointer-events: none;
}

.stories__header__grid {
    display: grid;
    grid-template-columns: 1fr 1fr;
    align-items: center;
    gap: var(--space-64);
    padding-left: 0;
    margin-bottom: var(--space-96);
}

.stories__header__copy {
    padding-right: 8rem;
}

.stories__search__wrapper {
    padding-left: 8rem;
    padding-right: 8rem;
    margin-bottom: var(--space-64);
    display: flex;
    flex-direction: column;
    gap: var(--space-8);
}

.stories__search__title {
    color: var(--color-white);
    font-family: waverly-cf, sans-serif;
    font-size: 20px;
    font-style: normal;
    font-weight: 800;
    line-height: 150%;
    letter-spacing: 0.4px;
}

.stories__search__form {
    display: flex;
    gap: var(--space-16);
    margin-top: var(--space-8);
    max-width: 550px;
}

.stories__search__form input[type="text"] {
    border: 3px solid var(--color-white);
    background: var(--color-dark-blue);
    padding: 12px 16px;
    color: var(--color-white);
    font-family: itc-avant-garde-gothic-pro, sans-serif;
    font-size: 16px;
    width: 100%;
    outline: none;
    transition: border 0.3 ease;
}

.stories__search__form input[type="text"]:focus {
    border: 3px solid var(--color-blue);
}

.stories__search__form input[type="text"]::placeholder {
    color: #B7B7B7;
}

.stories__search__form button {
    cursor: pointer;
    outline: none;
}

.stories__cards__grid {
    display: flex;
    flex-wrap: wrap;
    justify-content: center;
    gap: var(--space-32);
    padding: 0 4rem;
}

.review__card:nth-of-type(odd) {
    transform: rotate(-2deg);
}

.review__card:nth-of-type(even) {
    transform: rotate(2deg);
}

.form__cta__submit {
    display: flex;
    align-items: center;
    gap: var(--space-32);
}

.form__divider {
    border: none;
    background-color: var(--color-white);
    height: 3px;
    width: 100%;
    max-width: 440px;
    margin: 0;

}


.form__privacy__notice {
    color: var(--color-white);
    font-family: itc-avant-garde-gothic-pro, sans-serif;
    font-size: 12px;
    font-weight: 500;
    line-height: 150%;
    max-width: 500px;
    background-color: var(--color-dark-blue);
    padding: 12px;
    margin-top: var(--space-16);
}

.form__privacy__notice a {
    color: var(--color-orange);
    text-decoration: none;
    transition: color 0.3s ease;
}

.form__privacy__notice a:hover {
    color: var(--color-white);
    text-decoration: underline;
}




.toast__notification {
    position: fixed;
    top: 120px;
    left: 50%;
    transform: translateX(-50%);
    background-color: var(--color-blue);
    color: var(--color-white);
    padding: 16px 32px;
    border: 3px solid var(--color-blue);
    border-radius: 0;

    display: flex;
    align-items: center;
    gap: var(--space-32);
    z-index: 999;
    box-shadow: 0 4px 4px rgba(0, 0, 0, 0.25);
    font-family: itc-avant-garde-gothic-pro, sans-serif;
    font-size: 16px;
    animation: toastTimer 10s forwards;
}

.toast__notification p {
    margin: 0;
    font-weight: 800;
}

.button__delete__story {
    display: inline-flex;
    font-family: waverly-cf, sans-serif;
    font-size: 14px;
    font-style: normal;
    font-weight: 900;
    line-height: normal;
    letter-spacing: 0.4px;
    text-decoration: none;

    padding: 14px 16px;
    justify-content: center;
    align-items: center;
    gap: 10px;
    background: transparent;
    box-shadow: 0 4px 4px 0 rgba(0, 0, 0, 0.15);
    border: 3px solid var(--color-white);
    color: var(--color-white);
    transition: all 0.3s ease-in-out;
}


.button__delete__story:hover {
    color: var(--color-blue);
    background: var(--color-white);
}

@keyframes toastTimer {
    0% {
        opacity: 0;
        transform: translate(-50%, -20px);
    }

    5% {
        opacity: 1;
        transform: translate(-50%, 0px);
    }

    95% {
        opacity: 1;
        transform: translate(-50%, 0px);
    }

    100% {
        opacity: 0;
        transform: translate(-50%, -20px);
        visibility: hidden;
    }
}